/***********************************************************************/
/*                                                                     */
/*  FILE        :Main.c or Main.cpp                                    */
/*  DATE        :Tue, Oct 31, 2006                                     */
/*  DESCRIPTION :Main Program                                          */
/*  CPU TYPE    :                                                      */
/*                                                                     */
/*  NOTE:THIS IS A TYPICAL EXAMPLE.                                    */
/*                                                                     */
/***********************************************************************/

/*******************************************************************************
Includes <System Includes> , "Project Includes"
*******************************************************************************/
//#include "typedefine.h"
#include "iodefine.h"
#include "stdbool.h"
#include "R_PG_DTC_RX210.h"
#include <string.h>

/*******************************************************************************
Macro definitions
*******************************************************************************/
#define BUFF_SIZE       (13)                        /* setting buffer size */
#define VECT_SIZE       (256)                       /* Vector Table size */
#define DEST_SIZE       (16)                        /* Destination Table size */

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/
void main(void);

/*******************************************************************************
* Destination_Table
*******************************************************************************/
#pragma address dtc_destination_table = 0x00003000
uint32_t dtc_destination_table [DEST_SIZE];

/*******************************************************************************
* DTC Vector_Table
*******************************************************************************/
#pragma address dtc_vector_table = 0x00002000
uint32_t dtc_vector_table [VECT_SIZE];

/*******************************************************************************
* Constant Definition
*******************************************************************************/
const uint8_t send_buf[BUFF_SIZE] = "Hello World!"; /* send data from SCI0 to SCI5 */


/*******************************************************************************
* Private global variables and functions
*******************************************************************************/
#pragma address CH0_read_buf = 0x00002e00
uint8_t CH0_read_buf[BUFF_SIZE] = "";                    /* read buffer for SCI0 */

#pragma address CH5_read_buf = 0x00002f00
uint8_t CH5_read_buf[BUFF_SIZE] = "";                    /* read buffer for SCI5 */

/*******************************************************************************
* Function Name: main
* Description  : Main program
* Arguments    : none
* Return Value : none
*******************************************************************************/
void main(void)
{

    R_PG_SCI_ReceiveAllData_C5(CH5_read_buf, BUFF_SIZE);        /* Receive from SCI0 */  
    R_PG_SCI_SendAllData_C0((uint8_t *)send_buf, BUFF_SIZE);    /* Send data to SCI5 */ 

    while(1);
}

/*******************************************************************************
* Function Name: Sci0TrFunc
* Description  : Finish sending(SCI0)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci0TrFunc(void)
{
    /* Do nothing */
}

/*******************************************************************************
* Function Name: Sci0ReFunc
* Description  : Finish receiving(SCI0)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci0ReFunc(void)
{
    R_PG_SCI_StopCommunication_C0();
    R_PG_SCI_StopCommunication_C5();

    /* send/receive OK ? */
    if ( 0 == strcmp((const char *)CH0_read_buf, (const char *)send_buf) )
    {
        R_PG_IO_PORT_Write_PH2(1);    /* Turn on D3 */
    }
    else
    {
        /* Do nothing */
    }
}

/*******************************************************************************
* Function Name: Sci5ReFunc
* Description  : Finish receiving(SCI5)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci5ReFunc(void)
{
    R_PG_SCI_StopCommunication_C0();
    R_PG_SCI_StopCommunication_C5();

    R_PG_SCI_ReceiveAllData_C0(CH0_read_buf, BUFF_SIZE);    /* Receive data */
    R_PG_SCI_SendAllData_C5(CH5_read_buf, BUFF_SIZE);  /* Send back to SCI0 */

}

/*******************************************************************************
* Function Name: Sci5TrFunc
* Description  : Finish sending(SCI5)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci5TrFunc(void)
{
    /* Do nothing */
}

/*******************************************************************************
* Function Name: Sci0ErFunc
* Description  : Receive error(SCI0)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci0ErFunc(void)
{
    /* Do nothing */
}

/*******************************************************************************
* Function Name: Sci5ErFunc
* Description  : Receive error(SCI5)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci5ErFunc(void)
{
    /* Do nothing */
}


/******************************************************************************
Option-Setting Memory
******************************************************************************/
#pragma address OFS1_REG = 0xFFFFFF88   /* OFS1 register */
const unsigned long OFS1_REG = 0xFFFFFFFF;

#pragma address OFS0_REG = 0xFFFFFF8C   /* OFS0 register */
const unsigned long OFS0_REG = 0xFFFFFFFF;
